@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 use smallnum;
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 our (%TOOL, $ANOBJECT);
 
@@ -117,7 +117,7 @@ BEGIN {
 				$h = $s = 0;
 			}
 			else {
-				$d = smallnum::smallnum($d); #grrr
+				$d = smallnum::_smallnum($d); #grrr
 				$s = $l > 0.5 ? ($d / ( 2 - $max - $min )) : ($d / ( $max + $min ));
 				$h = ( $max == $r )
 					? ( $g - $b ) / $d + ( $g < $b ? 6 : 0 )
@@ -309,7 +309,7 @@ sub fadein {
 	$hsl->{a} += ($meth && $meth eq 'relative')
 		? $hsl->{a} * $TOOL{depercent}($amt)
  		: $TOOL{depercent}($amt);
-	$hsl->{a} = smallnum::smallnum($hsl->{a});
+	$hsl->{a} = smallnum::_smallnum($hsl->{a});
 	return $colour->hsla( $TOOL{hash2array}( $hsl, 'h', 's', 'l', 'a' ) );
 }
 
@@ -412,7 +412,7 @@ Colouring::In - color or colour.
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =cut
 
